@@ -20,8 +20,8 @@
 class SlideShowCfg : public QWidget, public Ui::SlideShowCfg
 {
 public:
-  SlideShowCfg( QWidget *parent=0L ) : QWidget( parent ) {
-    setupUi( this );
+  SlideShowCfg( QWidget *parent ) : QWidget( parent ) {
+    setupUi( parent );
   }
 };
 
@@ -40,9 +40,6 @@ public:
 
   void restart();
 
-protected slots:
-  void slotTimeout();
-
 protected:
   /** Load list of images from directory */
   virtual void loadDirectory();
